@@ -1,11 +1,7 @@
-# encoding: utf-8
-
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-from __future__ import absolute_import, unicode_literals
-
 from .__version__ import __author__, __copyright__, __email__, __license__, __version__
 from ._config import ConfigItem, ConfigManager, DefaultDisplayStyle
 from ._const import NULL_VALUE
